#include <bastard.h>
#include <bdb.h>
#include <extension.h>


/* OUTPUT DIFF : Create binary diff of (patched) target */
int plugin_main(FILE *f)
{
	sys_msg("DIFF output not supported\n");
	return (0);
}
